/*
 *   This file is part of Dianara
 *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MINORFEED_H
#define MINORFEED_H

#include <QTextBrowser>
#include <QVBoxLayout>
#include <QLabel>
#include <QFont>
#include <QVariantList>

#include <QDebug>

#include "pumpcontroller.h"
#include "timestamp.h"
#include "mischelpers.h"


class MinorFeed : public QTextBrowser
{
    Q_OBJECT

public:
    explicit MinorFeed(PumpController *pumpController,
                       QWidget *parent = 0);

signals:

    
public slots:
    void updateFeed();
    void setFeedContents(QVariantList activitiesList);


private:
    PumpController *pController;

};

#endif // MINORFEED_H
